/***************************************************************************

  (c) 2012 Adrien Prokopowicz <prokopy@users.sourceforge.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  MA 02110-1301, USA.

***************************************************************************/

#ifndef HMAIN_H
#define HMAIN_H

#include "../gb.xml.h"

#ifndef __HMAIN_CPP
extern "C" XML_INTERFACE XML;
#endif

#if defined(OS_MACOSX) || defined(__APPLE__) || defined(__CYGWIN__)
#define memrchr(s, c, n) XML.memrchr(s, c, n)
#endif

#endif
